//! Resource records.

pub mod data;

mod opt;
pub use opt::*;

mod record;
pub use record::*;

mod record_set;
pub use record_set::*;
